/***************************************************************************
 *   Copyright (C) 2003 by Flameeyes                                       *
 *   dgp85@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
		 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#include "kvbapref.h"
#include "kvba.h"

#include <qstring.h>
#include <qlineedit.h>
#include <qcheckbox.h>
#include <qcombobox.h>
#include <qslider.h>

#include <kconfig.h>
#include <kfiledialog.h>
#include <kurlrequester.h>

kvbapref::kvbapref(QWidget *parent, const char *name, WFlags f)
 : KvbaPrefBase(parent, name, f)
{
	exePath->setMode(KFile::LocalOnly);
	dirStart->setMode(KFile::LocalOnly|KFile::Directory);
	biosFile->setMode(KFile::LocalOnly);
	cfgFile->setMode(KFile::LocalOnly);
	
	loadPrefs();
}

void kvbapref::loadPrefs()
{
	KGlobal::config()->setGroup("general");
		exePath->setURL(KGlobal::config()->readEntry( "exepath", "" ));
		dirStart->setURL(KGlobal::config()->readEntry( "startdir", "" ));
		biosFile->setURL(KGlobal::config()->readEntry( "biosfile", "" ));
		cfgFile->setURL(KGlobal::config()->readEntry( "cfgfile", "" ));
		vbaVersion->setCurrentItem(KGlobal::config()->readNumEntry( "vbaversion", 0 ));

	KGlobal::config()->setGroup("features");
		rtcEnabled->setChecked(KGlobal::config()->readBoolEntry( "rtc", true ));
		agbEnabled->setChecked(KGlobal::config()->readBoolEntry( "agb", true ));
		pwiEnabled->setChecked(KGlobal::config()->readBoolEntry( "pwi", true ));
		ssType->setCurrentItem(KGlobal::config()->readNumEntry( "showspeed", 0 ));
		flashSize->setCurrentItem(KGlobal::config()->readNumEntry( "flashsize", 0 ));
		throttleEnabled->setChecked(KGlobal::config()->readBoolEntry( "throttleenabled", false ));
		throttleValue->setText(QString::number(KGlobal::config()->readNumEntry( "throttlevalue", 5 )));
		saveType->setCurrentItem(KGlobal::config()->readNumEntry( "savetype", 0 ));

	KGlobal::config()->setGroup("graphics");
		zoomSelect->setCurrentItem(KGlobal::config()->readNumEntry( "zoom", 0 ));
		afsEnabled->setChecked(KGlobal::config()->readBoolEntry( "afs", false ));
		fullEnabled->setChecked(KGlobal::config()->readBoolEntry( "full", false ));
		frameSkip->setValue(KGlobal::config()->readNumEntry( "frameskip", 0 ));
		filter->setCurrentItem(KGlobal::config()->readNumEntry( "filter", 0 ));
		yuvEnabled->setChecked(KGlobal::config()->readBoolEntry( "yuvenabled", false ));
		yuvOverlay->setCurrentItem(KGlobal::config()->readNumEntry( "yuv", 0 ));
		ifbType->setCurrentItem(KGlobal::config()->readNumEntry( "ifb", 0 ));
}

kvbapref::~kvbapref()
{
}

void kvbapref::accept()
{
	KGlobal::config()->setGroup("general");
		KGlobal::config()->writeEntry( "exepath", KURL( exePath->url() ).path() );
		KGlobal::config()->writeEntry( "startdir", KURL( dirStart->url() ).path() );
		KGlobal::config()->writeEntry( "biosfile", KURL( biosFile->url() ).path() );
		KGlobal::config()->writeEntry( "cfgfile", KURL( cfgFile->url() ).path() );
		KGlobal::config()->writeEntry( "vbaversion", vbaVersion->currentItem());

	KGlobal::config()->setGroup("features");
		KGlobal::config()->writeEntry( "rtc", rtcEnabled->isChecked());
		KGlobal::config()->writeEntry( "agb", agbEnabled->isChecked());
		KGlobal::config()->writeEntry( "pwi", pwiEnabled->isChecked());
		KGlobal::config()->writeEntry( "showspeed", ssType->currentItem());
		KGlobal::config()->writeEntry( "flashsize", flashSize->currentItem());
		KGlobal::config()->writeEntry( "throttleenabled", throttleEnabled->isChecked());
		KGlobal::config()->writeEntry( "throttlevalue", throttleValue->text().toInt());
		KGlobal::config()->writeEntry( "savetype", saveType->currentItem());

	KGlobal::config()->setGroup("graphics");
		KGlobal::config()->writeEntry( "zoom", zoomSelect->currentItem());
		KGlobal::config()->writeEntry( "afs", afsEnabled->isChecked());
		KGlobal::config()->writeEntry( "full", fullEnabled->isChecked());
		KGlobal::config()->writeEntry( "frameskip", frameSkip->value());
		KGlobal::config()->writeEntry( "filter", filter->currentItem());
		KGlobal::config()->writeEntry( "yuvenabled", yuvEnabled->isChecked());
		KGlobal::config()->writeEntry( "yuv", yuvOverlay->currentItem());
		KGlobal::config()->writeEntry( "ifb", ifbType->currentItem());

	QDialog::accept();
}

void kvbapref::reject()
{
	QDialog::reject();
}

void kvbapref::throttleToggled(bool v)
{
	throttleValue->setEnabled(v);
}

void kvbapref::yuvEnabledToggled(bool v)
{
	yuvOverlay->setEnabled(v);
}
